@@ -61,6 +61,14 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 #include "lrmi.h"
 
+/* 2.6.26+ kernels don't define the legacy masks. */
+#if defined(__linux__) && !defined(TF_MASK)
+	#define TF_MASK X86_EFLAGS_TF
+	#define IF_MASK X86_EFLAGS_IF
+	#define VIF_MASK X86_EFLAGS_VIF
+	#define IOPL_MASK X86_EFLAGS_IOPL
+#endif
+
 #define REAL_MEM_BASE 	((void *)0x10000)
 #define REAL_MEM_SIZE 	0x40000
 #define REAL_MEM_BLOCKS 	0x100
@@ -340,7 +348,7 @@ LRMI_init(void)
 	}
 
 	if (!map_file((void *)0xa0000, 0x100000 - 0xa0000,
-	 PROT_READ | PROT_WRITE,
+	 PROT_READ | PROT_WRITE | PROT_EXEC,
 	 MAP_FIXED | MAP_SHARED, "/dev/mem", 0xa0000)) {
 		munmap((void *)0, 0x502);
 		real_mem_deinit();
